StorageManager

Struct StorageManager 

pub struct StorageManager { /* private fields */ }
Manage all storage providers.

Example

use dispnet_storage::storage_manager::StorageManager;
 
let mut manager = StorageManager::new();

Implementations

Source

impl StorageManager

pub fn new() -> Self

pub fn add_storage_provider( &mut self, layer_key: String, provider: Box<dyn StorageProvider>, )

Add a storage provider instance to the manager

pub fn remove_storage_provider(&mut self, layer_key: &str)

Remove a loaded storage provider instance

pub fn get_storage_provider_layers(&self) -> Vec<&String>

Get all layers.

Layers are the names of storage provider instances.

pub fn get(&self, layer_key: &str, key: &str) -> Result<GetData, String>

Get data from a storage layer with a key.

pub fn find(&self, key: &str) -> Result<GetData, String>

Find the first data entry for the key in any storage provider.

pub fn save( &self, layer_key: &str, key: &str, raw: Vec<u8>, ) -> Result<SaveData, String>

Save data to the storage layer.

pub fn delete(&self, layer_key: &str, key: &str)

Queue an entry for deletion in a specific layer.

pub fn delete_all(&self, key: &str)

Queue for deletion all entires which match the key on any layer.

pub fn free(&self)

Execute free on all layers.

pub fn force_free(&self, all: bool)

Executes force free on all layers.